﻿using System.Windows;
using System.Windows.Controls;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WpfDesktopEdition;

namespace CSHowDoISamples
{
    public partial class DisplayASimpleMap : UserControl
    {
        public DisplayASimpleMap()
        {
            InitializeComponent();
        }

        private void WpfMap_Loaded(object sender, RoutedEventArgs e)
        {
            Map1.MapUnit = GeographyUnit.Meter;
            Map1.CurrentExtent = new RectangleShape(-10000000, 5000000, 10000000, -5000000);

            Map1.BackgroundOverlay.BackgroundBrush = new GeoSolidBrush(GeoColor.FromArgb(255, 198, 255, 255));

            ManagedProj4Projection proj4 = new ManagedProj4Projection();
            proj4.InternalProjectionParametersString = ManagedProj4Projection.GetWgs84ParametersString();
            proj4.ExternalProjectionParametersString = ManagedProj4Projection.GetSphericalMercatorParametersString();

            ShapeFileFeatureLayer worldLayer = new ShapeFileFeatureLayer(@"..\..\SampleData\Data\Countries02.shp");
            worldLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.Country1;
            worldLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            worldLayer.FeatureSource.Projection = proj4;
            worldLayer.Open();
            var wrappingExtent = worldLayer.GetBoundingBox();

            LayerOverlay layerOverlay = new LayerOverlay();
            layerOverlay.WrappingExtent = wrappingExtent;
            layerOverlay.WrappingMode = WrappingMode.WrapDateline;
            layerOverlay.Layers.Add("worldLayer", worldLayer);

            Map1.Overlays.Add("WorldOverlay", layerOverlay);

            PopupOverlay PopupOv = new PopupOverlay();
            Map1.Overlays.Add("PopupOverlay", PopupOv);

            //Show a popup on "Real" world
            double Easting = -410184;
            worldLayer.Open();

            double SphericalMercatorSpan = worldLayer.GetBoundingBox().Width;
            proj4.Close();
            worldLayer.Close();
            Point PopupLocation = new Point(Easting, 4971042);
            Popup RealWorldPopup = new Popup(PopupLocation);
            RealWorldPopup.Content = "Real";
            PopupOv.Popups.Add(RealWorldPopup);

            //Show a popup on "West virtual" world

            PopupLocation.X = -SphericalMercatorSpan + Easting; //Longitude span is negative because we go the west
            Popup LeftVirtualWorldPopup = new Popup(PopupLocation);
            LeftVirtualWorldPopup.Content = "Left Virtual";
            PopupOv.Popups.Add(LeftVirtualWorldPopup);

            //Show a popup on "East virtual" world

            PopupLocation.X = SphericalMercatorSpan + Easting;  //Longitude span is positive because we go to the east
            Popup RightVirtualWorldPopup = new Popup(PopupLocation);
            RightVirtualWorldPopup.Content = "Right Virtual";
            PopupOv.Popups.Add(RightVirtualWorldPopup);

            InMemoryFeatureLayer featureLayer = new InMemoryFeatureLayer();
            featureLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = PointStyles.City1;
            featureLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            LayerOverlay layerOverlay1 = new LayerOverlay();
            layerOverlay1.WrappingExtent = wrappingExtent;

            layerOverlay1.WrappingMode = WrappingMode.WrapDateline;
            layerOverlay1.Layers.Add("featureLayer", featureLayer);
            featureLayer.InternalFeatures.Add(new Feature(new PointShape(-410184, 4971042)));

            Map1.Overlays.Add(layerOverlay1);
            //Map1.ZoomLevelSet = GetCustomZoomLevelSet(591330330.94349861);

            Map1.Refresh();

        }

        private static ZoomLevelSet GetCustomZoomLevelSet(double maxScale)
        {
            ZoomLevelSet zoomLevelSet = new ZoomLevelSet();
            int i = 0;
            while (i++ < 20)
            {
                zoomLevelSet.CustomZoomLevels.Add(new ZoomLevel(maxScale));
                maxScale /= 2d;
            }

            return zoomLevelSet;
        }
    }
}
